@@ -9,6 +9,8 @@
  */
 #pragma once
 
+#include <config.h>
+
 /**
  * Returns the output container below the given output container.
  *
@@ -22,6 +24,12 @@ Con *output_get_content(Con *output);
  */
 Output *get_output_from_string(Output *current_output, const char *output_str);
 
+/**
+ * Returns the output for the given con.
+ *
+ */
+Output *get_output_for_con(Con *con);
+
 /**
  * Iterates over all outputs and pushes sticky windows to the currently visible
  * workspace on that output.
