@@ -1,5 +1,3 @@
-#undef I3__FILE__
-#define I3__FILE__ "click.c"
 /*
  * vim:ts=4:sw=4:expandtab
  *
@@ -187,11 +185,10 @@ static int route_click(Con *con, xcb_button_press_event_t *event, const bool mod
      * default behavior. */
     if (dest == CLICK_DECORATION || dest == CLICK_INSIDE || dest == CLICK_BORDER) {
         Binding *bind = get_binding_from_xcb_event((xcb_generic_event_t *)event);
-        /* clicks over a window decoration will always trigger the binding and
-         * clicks on the inside of the window will only trigger a binding if
-         * the --whole-window flag was given for the binding. */
-        if (bind && ((dest == CLICK_DECORATION || bind->whole_window) ||
-                     (dest == CLICK_BORDER && bind->border))) {
+
+        if (bind != NULL && (dest == CLICK_DECORATION ||
+                             (dest == CLICK_INSIDE && bind->whole_window) ||
+                             (dest == CLICK_BORDER && bind->border))) {
             CommandResult *result = run_binding(bind, con);
 
             /* ASYNC_POINTER eats the event */
