@@ -1,5 +1,3 @@
-#undef I3__FILE__
-#define I3__FILE__ "move.c"
 /*
  * vim:ts=4:sw=4:expandtab
  *
@@ -101,8 +99,7 @@ static void attach_to_workspace(Con *con, Con *ws, direction_t direction) {
  */
 static void move_to_output_directed(Con *con, direction_t direction) {
     Con *old_ws = con_get_workspace(con);
-    Con *current_output_con = con_get_output(con);
-    Output *current_output = get_output_by_name(current_output_con->name);
+    Output *current_output = get_output_for_con(con);
     Output *output = get_output_next(direction, current_output, CLOSEST_OUTPUT);
 
     if (!output) {
@@ -206,6 +203,7 @@ void tree_move(Con *con, int direction) {
 
                 DLOG("Swapped.\n");
                 ipc_send_window_event("move", con);
+                ewmh_update_wm_desktop();
                 return;
             }
 
@@ -214,6 +212,7 @@ void tree_move(Con *con, int direction) {
                  *  try to move it to a workspace on a different output */
                 move_to_output_directed(con, direction);
                 ipc_send_window_event("move", con);
+                ewmh_update_wm_desktop();
                 return;
             }
 
@@ -274,4 +273,5 @@ end:
 
     tree_flatten(croot);
     ipc_send_window_event("move", con);
+    ewmh_update_wm_desktop();
 }
